function find_dist2(Object1, Object2)
% find_dist calculates the approximate 2-D distance
% between two objects on the moon (i.e. Surveyor
% and Apollo landings/crashes)
% usage moondist = find_dist(Object1, Object2)
%
%   Object1,2 are numbers (1 to 46) denoting structures
%   containing:
    %	Object = name of object 1
    %	Latitude = latitude of object 1, str
    %   Latdir = direction (S or N), str
    %	Longitude = longitude of object 1, str
    %   Longdir = direction (W or E), str
%
%   Ben Clarke, Georgia Institute of Technology
%   c/o VagaLune SarL (c) 2007.

load moon_land

obj1 = char(Object(Object1) );
lat1 = str2double(Latitude(Object1) );
dlat1 = char(Latdir(Object1) );
long1 = str2double(Longitude(Object1) );
dlong1 = char(Longdir(Object1) );

obj2 = char(Object(Object2) );
lat2 = str2double(Latitude(Object2) );
dlat2 = char(Latdir(Object2) );
long2 = str2double(Longitude(Object2) );
dlong2 = char(Longdir(Object2) );

% Moon parameters of interest
Rmoon = 1738.1e3;       % equitorial radius of moon, m
Rpmoon = 1736e3;        % polar radius of moon, m

Cmoon = pi*2*Rmoon;     % equit circum of moon, m
dist_deg = Cmoon/360;   % distance per degree of longitude
Cpmoon = pi*2*Rpmoon;   % polar circum of moon, m
dist_degp = (0.5*Cpmoon)/180;   % distance per degree of latitude

% two-dimensional distance between Apollo 12 and 14
if (dlat1 == dlat2)
    dlat = (lat1-lat2)*dist_degp; % differential lat
else
    dlat = (lat1+lat2)*dist_degp; % differential lat
end
if (dlong1 == dlong2)
    dlong = (long1-long2)*dist_deg; % differential long
else
    dlong = ((360-long1)-long2)*dist_deg; % differential long
end

moondist = sqrt(dlat^2 + dlong^2);   % distance between Ap14 and Ap12

disp(['The distance from ', obj1, ' to ', obj2, ' is ', num2str(moondist/1000), ' km']);

% whew, learn that its 181km between Ap12 and Ap14.  too far for a rover.

